/*
* JBoss, Home of Professional Open Source
* Copyright 2005, JBoss Inc., and individual contributors as indicated
* by the @authors tag. See the copyright.txt in the distribution for a
* full listing of individual contributors.
*
* This is free software; you can redistribute it and/or modify it
* under the terms of the GNU Lesser General Public License as
* published by the Free Software Foundation; either version 2.1 of
* the License, or (at your option) any later version.
*
* This software is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with this software; if not, write to the Free
* Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
* 02110-1301 USA, or see the FSF site: http://www.fsf.org.
*/
package org.jboss.security.federation.model;

import java.io.Serializable;

/**
 * A Partner object represents a SSO Federation's partner web-site/web application.
 * 
 * 
 * @author Sohil Shah - sohil.shah@jboss.com - May 28, 2006
 *
 */
public class Partner implements Serializable 
{
    private String federationServer = null;
    private String domain = null;
    
    /**
     * Initializes a Partner object
     *
     */
    public Partner()
    {
        
    }

    /**
     * Returns the security ala web domain which this <b>Partner</b> web application is hosted in.
     * 
     * @return web domain value of the partner application
     */
    public String getDomain() 
    {
        return domain;
    }

    /**
     * Sets the security ala web domain which this <b>Partner</b> web application is hosted in.
     * 
     * @param domain value of the security domain
     */
    public void setDomain(String domain) 
    {
        this.domain = domain;
    }

    /**
     * Returns the web address of the Federation Server that powers the security ala web domain that this partner application resides in.
     * 
     * @return web address of the Federation Server
     */
    public String getFederationServer() 
    {
        return federationServer;
    }

    /**
     * Sets the web address of the Federation Server that powers the security ala web domain that this partner application resides in.
     * 
     * @param federationServer value of the federation server's web address
     */
    public void setFederationServer(String federationServer) 
    {
        this.federationServer = federationServer;
    }        
}
