/*
* JBoss, Home of Professional Open Source
* Copyright 2005, JBoss Inc., and individual contributors as indicated
* by the @authors tag. See the copyright.txt in the distribution for a
* full listing of individual contributors.
*
* This is free software; you can redistribute it and/or modify it
* under the terms of the GNU Lesser General Public License as
* published by the Free Software Foundation; either version 2.1 of
* the License, or (at your option) any later version.
*
* This software is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with this software; if not, write to the Free
* Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
* 02110-1301 USA, or see the FSF site: http://www.fsf.org.
*/
package org.jboss.security.federation.service;


/**
 * A Trust Service represents the SSO Trust component of the Federation Service. A Trust Service makes sure that the 
 * assertions being processed by the Single Sign On components are valid. This is key to avoiding granting access to
 * unauthorized users
 * 
 * @author Sohil Shah - sohil.shah@jboss.com - Oct 31, 2006
 *
 */
public interface TrustService 
{
    /**
     * Generates a token secret understood by the Federation of partner applications only
     * 
     * @param tokenIdentifier an identifier that can associate a secret with the corresponding token
     * @return the secret
     */
    public String generateSecret(String tokenIdentifier);
    
    /**
     * Validates the secret associated with the token being processed by the Single Sign On components
     * 
     * @param tokenIdentifier an identifier that can associate a secret with the corresponding token
     * @param secret the secret associated with the token being processed by the Single Sign On components
     * @return a status of whether this secret is valid or not
     */
    public String validateSecret(String tokenIdentifier,String secret);
}
