/*
* JBoss, Home of Professional Open Source
* Copyright 2005, JBoss Inc., and individual contributors as indicated
* by the @authors tag. See the copyright.txt in the distribution for a
* full listing of individual contributors.
*
* This is free software; you can redistribute it and/or modify it
* under the terms of the GNU Lesser General Public License as
* published by the Free Software Foundation; either version 2.1 of
* the License, or (at your option) any later version.
*
* This software is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with this software; if not, write to the Free
* Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
* 02110-1301 USA, or see the FSF site: http://www.fsf.org.
*/
package org.jboss.security.idm;

import java.io.Serializable;
import java.util.Map;
import java.util.HashMap;

/**
 * LoginContext encapsulates environment information to be passed to Single Sign On notifications.
 * 
 * <br/><br/>
 * 
 * Examples of such notifications are notifications that the LoginProvider receives to process an automatic login being
 * performed by the SSO Engine in response to processing a valid assertion from a partner site in the Federation
 * 
 * @author Sohil Shah - sohil.shah@jboss.com - Nov 15, 2006
 *
 */
public final class LoginContext implements Serializable
{
    private Map contextMap = null;
    
    /**
     * name of the attribute for storing http request object
     */
    public static final String HTTP_REQUEST = "http_request";
    
    /**
     * name of the attribute for storing http response object
     */
    public static final String HTTP_RESPONSE = "http_response";
    
    /**
     * name of the attribute for storing the SSOUser object representing the
     * user being authenticated by the SSO Engine
     */
    public static final String SSO_USER = "jboss_sso_user";
    
    
    /**
     * Initializer
     *
     */
    public LoginContext() 
    {
        super();
        this.contextMap = new HashMap();
    }
    
    /**
     * Returns value corresponding to the specified attribute name
     * 
     * @param name
     * @return
     */
    public Object getAttribute(String name)
    {
        return this.contextMap.get(name);
    }
    
    /**
     * Sets a specified value corresponding to the specified name in the context
     * 
     * @param name
     * @param value
     */
    public void setAttribute(String name,Object value)
    {
        this.contextMap.put(name,value);
    }
    
    
    /**
     * Returns an array of Strings consisting of all keys/names stored in the context
     * 
     * @return
     */
    public String[] getAttributeNames()
    {
      	  return (String[])this.contextMap.keySet().toArray(new String[0]);	
    }
}
