/*
* JBoss, Home of Professional Open Source
* Copyright 2005, JBoss Inc., and individual contributors as indicated
* by the @authors tag. See the copyright.txt in the distribution for a
* full listing of individual contributors.
*
* This is free software; you can redistribute it and/or modify it
* under the terms of the GNU Lesser General Public License as
* published by the Free Software Foundation; either version 2.1 of
* the License, or (at your option) any later version.
*
* This software is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with this software; if not, write to the Free
* Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
* 02110-1301 USA, or see the FSF site: http://www.fsf.org.
*/
package org.jboss.security.util;

import java.io.ByteArrayOutputStream;
import java.io.InputStream;
import java.security.MessageDigest;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.StringTokenizer;

import javax.servlet.http.Cookie;
import javax.servlet.http.HttpServletRequest;
import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;

import org.apache.xerces.jaxp.DocumentBuilderFactoryImpl;
import org.w3c.dom.Document;


/**
 * A general utitity class
 * 
 * @author Sohil Shah - sohil.shah@jboss.com - May 30, 2006
 *
 */
public class Tools 
{
    /**
     * Returns a one way hashed password based on the specified algorithm
     * 
     * @param clearPassword
     * @param hashAlgorithm
     * @return
     * @throws Exception
     */
    public static String getEncodedPassword(String clearPassword,String hashAlgorithm) throws Exception
    {
        byte[] hash = null;
        
        MessageDigest md = MessageDigest.getInstance(hashAlgorithm);
        md.update(clearPassword.getBytes());
        hash = md.digest();
        
        String hashPassword = Tools.encodeHex(hash);
        
        return hashPassword;
    }
           
    /**
     * Returns a hex encoded String representing the input byte array
     * 
     * @param bytes
     * @return a hex encoded String
     */
    public static String encodeHex(byte[] bytes)
    {
        String encodedStr = null;
        
        //perform hex encoding of bytes
        if(bytes!=null)
        { 
            byte ch = 0x00;
            int i = 0;             
            String pseudo[] = {"0", "1", "2","3", "4", "5", "6", "7", "8","9", "A", "B", "C", "D", "E","F"};

            StringBuffer out = new StringBuffer(bytes.length * 2);
            
            while(i < bytes.length) 
            {
                ch = (byte) (bytes[i] & 0xF0); // Strip off high nibble

                ch = (byte) (ch >>> 4); // shift the bits down

                ch = (byte) (ch & 0x0F); //must do this is high order bit is on!

                out.append(pseudo[(int) ch]); // convert the nibble to a String Character

                ch = (byte) (bytes[i] & 0x0F); // Strip off low nibble 

                out.append(pseudo[ (int) ch]); // convert the nibble to a String Character

                i++;
            }

            encodedStr = out.toString().toLowerCase();
        }
        
        return encodedStr;
    }
    
    
    
    
    /**
     * Checks if an SSOToken is sent in as a cookie on the http request
     * 
     * @param request
     * @param cookieName
     * @return
     */
    public static boolean isCookieFound(HttpServletRequest request,String cookieName)
    {
        boolean cookieFound = false;
        
        Cookie[] cookies = request.getCookies();
        if(cookies!=null)
        {
            for(int i=0;i<cookies.length;i++)
            {
                Cookie cookie = cookies[i];
                
                if(cookie.getName()!=null && cookie.getName().trim().equals(cookieName))
                {
                    cookieFound = true;
                    break;
                }                
            }
        }
        
        return cookieFound;
    }
    
    /**
     * cleans up the xml
     * 
     * @param xml
     * @return
     */
    public static String escapeStr(String xml)
    {                
        StringBuffer buffer = new StringBuffer();
        for(int i = 0;i < xml.length();i++)
        {
           char c = xml.charAt(i);
           if(c == '<')
           {
              buffer.append("&lt;");
           }           
           else if(c == '>')
           {
              buffer.append("&gt;");
           }
           else if(c == '&')
           {
              buffer.append("&amp;");
           }
           else if(c == '"')
           {
              buffer.append("&quot;");
           }
           else if(c == '\'')
           {
              buffer.append("&apos;");
           }
           else
           {
              buffer.append(c);
           }
        }
        return buffer.toString();
    }
    
    /**
     * Checks if this is an empty string
     * 
     * @param cour
     * @return
     */ 
    public static boolean isEmpty(String cour)
    {
        boolean isEmpty = false;
        if(cour==null || cour.trim().length()==0)
        {
            isEmpty = true;
        }
        return isEmpty;
    }
    
    /**
     * Checks if this is an empty array
     * 
     * @param cour
     * @return
     */
    public static boolean isEmpty(Object[] cour)
    {
        boolean isEmpty = false;
        if(cour==null || cour.length==0)
        {
            isEmpty = true;
        }
        return isEmpty;
    }
    
    /**
     * Checks if this is an empty collection
     * 
     * @param cour
     * @return
     */
    public static boolean isEmpty(Collection cour)
    {
        boolean isEmpty = false;
        if(cour==null || cour.size()==0)
        {
            isEmpty = true;
        }
        return isEmpty;
    }
    
    /**
     * parses an xml file and creates a DOM tree
     * 
     * @param is
     * @return
     * @throws Exception
     */
    public static Document parseXml(InputStream is)
    throws Exception
    {
        Document document = null;
        
        DocumentBuilderFactory factory = DocumentBuilderFactoryImpl.newInstance();
        DocumentBuilder builder = factory.newDocumentBuilder();
        
        document = builder.parse(is);
        
        return document;
    }  
    
    /**
     * Extracts a byte array from an InputStream
     * 
     * @param is
     * @return
     * @throws Exception
     */
    public static byte[] getBytes(InputStream is)
    throws Exception
    {
        byte[] data = null;
        
        Collection chunks = new ArrayList();
        byte[] buffer = new byte[1024*1000];
        int read = -1;
        int size = 0;
        
        while((read=is.read(buffer))!=-1)
        {
            if(read>0)
            {
                byte[] chunk = new byte[read];
                System.arraycopy(buffer,0,chunk,0,read);
                chunks.add(chunk);
                size += chunk.length;
            }
        }       
        
        if(size>0)
        {
            ByteArrayOutputStream bos = null;
            try
            {
                bos = new ByteArrayOutputStream(size);
                for(Iterator itr=chunks.iterator();itr.hasNext();)
                {
                    byte[] chunk = (byte[])itr.next();
                    bos.write(chunk);
                }
                data = bos.toByteArray();
            }
            finally
            {
                if(bos!=null)
                {
                    bos.close();
                }
            }
        }
        return data;
    } 
    
    /**
     * 
     * @param source
     * @param tobeReplaced
     * @param replaceWith
     * @return
     */
    public static String replaceStr(String source,String toBeReplaced,String replaceWith)
    {    	
    	StringBuffer buffer = new StringBuffer();
    	
    	StringTokenizer st = new StringTokenizer(source,toBeReplaced);
    	if(st.countTokens()>0)
    	{
    		while(st.hasMoreTokens())
    		{
    			String token = st.nextToken();
    			buffer.append(token);
    			buffer.append(replaceWith);
    		}
    	}
    	else
    	{
    		//nothing to replace
    		buffer.append(source);
    	}
    	    	
    	return buffer.toString();
    }
}
